@@ -12,10 +12,11 @@ def numberToBase(n, b):
         n //= b
     return digits[::-1]
 
-def run(code, _stack=(), _lst=()):
+def run(code, _stack=(), _lst=(), u=None, _inputs=()):
     index = 0
     stack = List(_stack)
     lst = List(_lst)
+    inputs = List(_inputs)
     while index < len(code):
         char = code[index]
         if char in '0123456789.':
@@ -48,12 +49,16 @@ def run(code, _stack=(), _lst=()):
             stack.push(eval(string))
         elif char == 'i':
             stack.push(int(input()))
+            inputs.push(stack[0])
         elif char == 'I':
             stack.push(list(map(int, input().split())))
+            inputs.push(stack[0])
         elif char == 't':
             stack.push(input())
+            inputs.push(stack[0])
         elif char == 'T':
             stack.push(input().split())
+            inputs.push(stack[0])
         elif char == 's':
             stack.push(list(stack).copy())
         elif char == 'S':
@@ -68,7 +73,7 @@ def run(code, _stack=(), _lst=()):
             stack.push(gcd(stack.first(list)))
         elif char == 'L':
             stack.push(lcm(stack.first(list)))
-        elif char == 'a':
+        elif char == 'k':
             stack.push(statistics.mean(stack.first(list) or [0]))
         elif char == 'l':
             stack.push([])
@@ -85,7 +90,7 @@ def run(code, _stack=(), _lst=()):
                 stack.push(''.join(reversed(a)))
         elif char == 'D':
             stack.push(list(set(stack.first(list))))
-        elif char == 'p':
+        elif char == 'r':
             a, b = stack.first(str, n=2)
             stack.push(b.split(a))
         elif char == 'J':
@@ -146,7 +151,7 @@ def run(code, _stack=(), _lst=()):
         elif char == '%':
             b, a = stack.first((int, float), n=2)
             stack.push(a % b)
-        elif char == 'D':
+        elif char == 'K':
             b, a = stack.first((int, float), n=2)
             stack.remove(a)
             stack.remove(b)
@@ -198,9 +203,9 @@ def run(code, _stack=(), _lst=()):
             except:
                 pass
             if stack[0]:
-                stack, lst = run(if_true, stack, lst)
+                stack, lst = run(if_true, stack, lst, u, inputs)
             else:
-                stack, lst = run(if_false, stack, lst)
+                stack, lst = run(if_false, stack, lst, u, inputs)
         elif char == '{':
             string = ''
             index += 1
@@ -212,7 +217,7 @@ def run(code, _stack=(), _lst=()):
                 pass
             a = stack.first(str)
             for i in a:
-                stack, lst = run(string, [i] + stack, lst)
+                stack, lst = run(string, [i] + stack, lst, u, inputs)
         elif char == '[':
             string = ''
             index += 1
@@ -224,7 +229,7 @@ def run(code, _stack=(), _lst=()):
                 pass
             a = stack.first(list)
             for i in a:
-                stack, lst = run(string, [i] + stack, lst)
+                stack, lst = run(string, [i] + stack, lst, u, inputs)
         elif char == '\\':
             index += 1
             if isinstance(stack[0], str):
@@ -272,12 +277,12 @@ def run(code, _stack=(), _lst=()):
             a = stack.first((list, str))
             l = []
             for i in a:
-                stack, lst = run(string, [i] + stack, lst)
+                stack, lst = run(string, [i] + stack, lst, u, inputs)
                 l.append(stack[0])
             stack.push(l)
         elif char == 'E':
             while 1:
-                stack, lst = run(code[index+1:], stack, lst)
+                stack, lst = run(code[index+1:], stack, lst, u, inputs)
                 print(stack[0])
         elif char == 'g':
             stack.push(list(lst).copy())
@@ -289,6 +294,14 @@ def run(code, _stack=(), _lst=()):
             stack.push(ord(stack.first(str)))
         elif char == 'V':
             stack.push(chr(stack.first(int)))
+        elif char == 'U':
+            u = stack[0]
+        elif char == 'u':
+            stack.push(u)
+        elif char == '(':
+            stack.push(list(inputs).copy())
+        elif char == ')':
+            stack.push(inputs[0])
         else:
             if isinstance(stack[0], str):
                 stack[0] += code[index]
